@@ -1,4 +1,4 @@
-
+library(testthat)
 
 my_reg_data <- data.frame ( 
   geo = c("BE1", "HU102", "FR1", "FRB",
@@ -8,7 +8,6 @@ my_reg_data <- data.frame (
 
 validate_nuts_regions ( dat = my_reg_data )
 
-
 result1 <- validate_nuts_regions ( 
   dat = data.frame ( 
   geo =c("BE1", "HU102")), 
@@ -31,3 +30,18 @@ test_that("invalid dates give error message", {
     values = c(1,2)
   ), geo_var = "country"))
 })
+
+with_nuts_df <- data.frame ( 
+  nuts = c("DE1", "DE7", "HU1", "BE1"), 
+  values = c(1:4),
+  typology = rep("nuts1",4)
+)
+
+tested_with_nuts <- validate_nuts_regions(
+  dat = with_nuts_df,
+  geo_var = "nuts")
+
+test_that("Special column names do not cause confusion", {
+  expect_equal(all(tested_with_nuts$valid_2016), TRUE)
+  expect_equal(ncol(tested_with_nuts), 5)
+})
